@@ -15,8 +15,9 @@
 #
 #
 
-from extractor import Extractor
-from emailclients import clients
+from unforward.extractor import Extractor
+from unforward.emailclients import clients
+import unforward.test
 
 __all__ = ['Extractor', 'clients']
 
