@@ -15,7 +15,7 @@
 #
 #
 
-from emailclient import EmailClient
+from unforward.emailclients.emailclient import EmailClient
 
 
 class LotusNotesClient(EmailClient):
