@@ -28,7 +28,7 @@ import codecs
 
 def main():
     """ The main starting point for the unforward script."""
-    sys.stdin = codecs.getreader('utf-8')(sys.stdin)
+    #sys.stdin = codecs.getreader('utf-8')(sys.stdin)
     email_text = sys.stdin.read()
     
     extractor = unforward.Extractor()
